import * as insuranceClaimServices from '@/services/api/InsuranceClaim';
import * as insuranceOrderServices from '@/services/api/InsuranceOrder';
import { useQuery, useQueryClient } from '@tanstack/vue-query';

type UseInsuranceOrderMaterialListOptions = {
  insuranceOrderId: MaybeRef<string>;
};

export function useInsuranceOrderMaterialList({
  insuranceOrderId,
}: UseInsuranceOrderMaterialListOptions) {
  const { data: insuranceOrderMaterialList, refetch } = useQuery({
    queryKey: ['insuranceOrderServices/getInsuranceOrderMaterialList', insuranceOrderId],
    queryFn: async () => {
      let res = await insuranceOrderServices.getInsuranceOrderMaterialList(
        {
          id: unref(insuranceOrderId),
        },
        { showLoading: false }
      );
      return res;
    },
    placeholderData: () => [] as API.InsuranceOrderMaterialListOutput[],
    enabled: computed(() => !!unref(insuranceOrderId)),
  });

  return {
    insuranceOrderMaterialList,
    refetch,
  };
}

type UseInsurancePolicyPayOptions = {
  id: MaybeRef<string>;
};

export function useInsurancePolicyPay({ id }: UseInsurancePolicyPayOptions) {
  const { data: insurancePolicyPayList, isLoading } = useQuery({
    queryKey: ['insuranceOrderServices/getInsurancePolicyPay', id],
    queryFn: async () => {
      return await insuranceOrderServices.getInsurancePolicyPay({
        id: unref(id),
      });
    },
    placeholderData: () => [] as API.InsurancePolicyPayDto[],
  });

  return {
    insurancePolicyPayList,
    isLoading,
  };
}
